@@ -22,7 +22,7 @@ parameters of the analysis step, in the
 :attr:`aspecd.dataset.Dataset.analyses` attribute of the dataset.
 
 
-Generally, two types of analysis steps can be distinguished:
+Generally, three types of analysis steps can be distinguished:
 
 * Analysis steps for handling single datasets
 
@@ -32,6 +32,11 @@ Generally, two types of analysis steps can be distinguished:
 
   Shall be derived from :class:`aspecd.analysis.MultiAnalysisStep`.
 
+* Analysis steps aggregating the results of a SingleAnalysisStep for multiple
+  datasets
+
+  Handled by class :class:`aspecd.analysis.AggregatedAnalysisStep`.
+
 In the first case, the analysis is usually handled using the
 :meth:`analyse` method of the respective :obj:`aspecd.dataset.Dataset`
 object. Additionally, those analysis steps always only operate on the data
@@ -42,7 +47,11 @@ In the second case, the analysis step is handled using the :meth:`analyse`
 method of the :obj:`aspecd.analysis.AnalysisStep` object, and the datasets
 are stored as a list within the analysis step. As these analysis steps span
 several datasets. Analysis steps handling multiple datasets should
-always inherit from the :class:`aaspecd.analysis.MultiAnalysisStep` class.
+always inherit from the :class:`aspecd.analysis.MultiAnalysisStep` class.
+
+Performing a SingleAnalysisStep on multiple datasets and aggregating the
+results in a :class:`aspecd.dataset.CalculatedDataset` is the realm of the
+third type of analysis steps, :class:`aspecd.analysis.AggregatedAnalysisStep`.
 
 The module contains both, base classes for analysis steps (as detailed
 above) as well as a series of generally applicable analysis steps for all
@@ -265,6 +274,16 @@ class AnalysisStep:
         In case of a dataset, it is a calculated dataset
         (:class:`aspecd.dataset.CalculatedDataset`)
 
+    index : :class:`list`
+        Label for each element in :attr:`result`
+
+        Should only be set if :attr:`result` is a scalar or list.
+
+        The index will be used, *e.g.*, by :class:`AggregatedAnalysisStep`
+        and in tabular representations of the results.
+
+        .. versionadded:: 0.5
+
     description : :class:`str`
         Short description, to be set in class definition
 
@@ -278,21 +297,20 @@ class AnalysisStep:
         Use appropriate record types from the `bibrecord package
         <https://bibrecord.docs.till-biskup.de/>`_.
 
+        .. versionadded:: 0.4
+
     Raises
     ------
     aspecd.exceptions.MissingDatasetError
         Raised when no dataset exists to act on
 
-
-    .. versionchanged:: 0.4
-        New attribute :attr:`references`
-
     """
 
     def __init__(self):
         self.name = aspecd.utils.full_class_name(self)
         self.parameters = dict()
         self.result = None
+        self.index = []
         self.description = 'Abstract analysis step'
         self.comment = ''
         self.references = []
@@ -596,7 +614,7 @@ class MultiAnalysisStep(AnalysisStep):
     def __init__(self):
         super().__init__()
         self.datasets = []
-        self.description = 'Abstract analysis step for multiple dataset'
+        self.description = 'Abstract analysis step for multiple datasets'
 
     def analyse(self):
         """Perform the actual analysis on the given list of datasets.
@@ -625,7 +643,6 @@ class MultiAnalysisStep(AnalysisStep):
         """
         if not self.datasets:
             raise aspecd.exceptions.MissingDatasetError
-        super().analyse()
         self._check_applicability()
         self._sanitise_parameters()
         self._perform_task()
@@ -639,6 +656,122 @@ class MultiAnalysisStep(AnalysisStep):
                     message=message)
 
 
+class AggregatedAnalysisStep(AnalysisStep):
+    """
+    Perform a SingleAnalysisStep on multiple datasets and aggregate results.
+
+    Data analysis often involves performing one and the same analysis step
+    on a series of datasets and aggregate the results in a single
+    (calculated) dataset for further display, be it graphically or tabularly.
+
+    Attributes
+    ----------
+    datasets : :class:`list`
+        List of dataset the analysis step should be performed for
+
+    analysis_step : :class:`str`
+        Name of the analysis step to perform on the datasets
+
+        Should be a class name of an analysis step. Can be either a full
+        class name including package and module, or only the class name. In
+        the latter case, it will be looked up in 'aspecd.analysis'.
+
+    result : :class:`aspecd.dataset.CalculatedDataset`
+        Result of the aggregated analysis
+
+    Raises
+    ------
+    aspecd.exceptions.MissingDatasetError
+        Raised if no datasets are given
+
+    aspecd.exceptions.MissingAnalysisStepError
+        Raised if no analysis_step is given
+
+    ValueError
+        Raised if the actual AnalysisStep returns a dataset
+
+    Examples
+    --------
+    For convenience, a series of examples in recipe style (for details of
+    the recipe-driven data analysis, see :mod:`aspecd.tasks`) is given below
+    for how to make use of this class. The examples focus each on a single
+    aspect.
+
+    Let's assume that you want to extract the minima of a series of datasets:
+
+    .. code-block:: yaml
+
+        - kind: aggregatedanalysis
+          type: BasicCharacteristics
+          properties:
+            parameters:
+              kind: min
+          apply_to:
+            - dataset1
+            - dataset2
+          result: basic_characteristics
+
+
+    .. versionadded:: 0.5
+
+    """
+
+    def __init__(self):
+        super().__init__()
+        self.datasets = []
+        self.analysis_step = ''
+        self.description = 'Aggregated analysis step for multiple datasets'
+        self.result = self.create_dataset()
+        self._analysis_object = None
+
+    def analyse(self):
+        """
+        Perform the given analysis step on the list of datasets.
+
+        The name of the analysis step to be performed on the list of
+        datasets is provided in :attr:`analysis_step`. The analysis will
+        result in a :class:`aspecd.dataset.CalculatedDataset` with the
+        metadata regarding the calculation (type and parameters) set
+        accordingly to :attr:`analysis_step` and :attr:`parameters`.
+
+        """
+        self._check_and_prepare()
+        index = []
+        for dataset in self.datasets:
+            analysis_done = dataset.analyse(self._analysis_object)
+            self.result.data.data = np.append(self.result.data.data,
+                                              analysis_done.result)
+            index.append(dataset.label)
+        n_datasets = len(self.datasets)
+        # noinspection PyUnboundLocalVariable
+        if isinstance(analysis_done.result, list):
+            self.result.data.data = \
+                np.reshape(self.result.data.data, (n_datasets, -1))
+        self.result.data.axes[0].index = index
+
+    def _check_and_prepare(self):
+        if not self.datasets:
+            raise aspecd.exceptions.MissingDatasetError
+        if not self.analysis_step:
+            raise aspecd.exceptions.MissingAnalysisStepError
+        self._get_analysis_object()
+        if isinstance(self._analysis_object.result, aspecd.dataset.Dataset):
+            raise ValueError('Analysis step "%s" returns dataset' %
+                             self.analysis_step)
+
+    def _get_analysis_object(self):
+        try:
+            self._analysis_object = aspecd.utils.object_from_class_name(
+                self.analysis_step)
+        except ValueError:
+            self._analysis_object = aspecd.utils.object_from_class_name(
+                '.'.join(
+                    ['aspecd.analysis', self.analysis_step]))
+        for key, value in self.parameters.items():
+            # noinspection PyUnresolvedReferences
+            self._analysis_object.parameters[key] = value
+
+
 class BasicCharacteristics(SingleAnalysisStep):
     # noinspection PyUnresolvedReferences
     """
@@ -659,6 +792,9 @@ class BasicCharacteristics(SingleAnalysisStep):
 
             Valid values are "min", "max", "amplitude", and "area".
 
+            A special kind is "all", returning all characteristics. In this
+            case, output can only be "value" (the default).
+
         output : :class:`str`
             Kind of output: (intensity) value, axes value(s), or axes indices
 
@@ -668,7 +804,7 @@ class BasicCharacteristics(SingleAnalysisStep):
 
             Default: "value"
 
-    result :
+    result : :class:`float` | :class:`list`
         Characteristic(s) of the dataset.
 
         The actual return type depends on the type of characteristics and
@@ -679,9 +815,31 @@ class BasicCharacteristics(SingleAnalysisStep):
         ========================= ============= ==============
         min, max, amplitude, area value         :class:`float`
         min, max                  axes, indices :class:`list`
-        all                       value         :class:`dict`
+        all                       value         :class:`list`
         ========================= ============= ==============
 
+        The corresponding kind is set as index, hence it will be used by
+        :class:`AggregatedAnalysisStep` and included in the dataset output
+        by this step - and hence in tabular output created by
+        :class:`aspecd.table.Table`.
+
+    index : :class:`list`
+        Label for each element in :attr:`result`
+
+        Always reflecting the kind of characteristic(s) asked for. In case
+        of asking for values, it is a list of the kinds. In case of the
+        output set to axes or indices, it will be the kind followed by
+        either the axis quantity or "index#".
+
+        Assuming a 2D dataset with axes quantities set to "wavelength" and
+        "time" and asking for the minimum, the index will be
+        ``['min(wavelength)', 'min(time)']`` in case of output set to
+        axes, and ``['min(index0)', 'min(index1)']`` in case of output
+        set to indices.
+
+        The index will be used, *e.g.*, by :class:`AggregatedAnalysisStep`
+        and in tabular representations of the results.
+
 
     Raises
     ------
@@ -710,7 +868,7 @@ class BasicCharacteristics(SingleAnalysisStep):
          type: BasicCharacteristics
          properties:
            parameters:
-             type: min
+             kind: min
          result: min_of_dataset
 
     This would simply return the minimum (value) of a given dataset in the
@@ -725,7 +883,7 @@ class BasicCharacteristics(SingleAnalysisStep):
          type: BasicCharacteristics
          properties:
            parameters:
-             type: min
+             kind: min
              output: axes
          result: min_of_dataset
 
@@ -735,7 +893,8 @@ class BasicCharacteristics(SingleAnalysisStep):
     "amplitude" have no analogon on the axes.
 
     Sometimes, you are interested in getting the values of all
-    characteristics at once in form of a dictionary:
+    characteristics at once in form of a list, with the kind stored in
+    :attr:`index`:
 
     .. code-block:: yaml
 
@@ -743,7 +902,7 @@ class BasicCharacteristics(SingleAnalysisStep):
          type: BasicCharacteristics
          properties:
            parameters:
-             type: all
+             kind: all
          result: characteristics_of_dataset
 
     Make sure to understand the different types the result has depending on
@@ -752,6 +911,12 @@ class BasicCharacteristics(SingleAnalysisStep):
 
     .. versionadded:: 0.2
 
+    .. versionchanged:: 0.5
+
+        :attr:`result` is either scalar or list in all cases,
+        and :attr:`index` is set to kind, for use with
+        :class:`AggregatedAnalysisStep` and tabular output.
+
     """
 
     def __init__(self):
@@ -781,12 +946,9 @@ class BasicCharacteristics(SingleAnalysisStep):
                 kind=self.parameters["kind"],
                 output=self.parameters["output"])
         if self.parameters["kind"] == "all":
-            self.result = {
-                'min': self._get_characteristic("min"),
-                'max': self._get_characteristic("max"),
-                'amplitude': self._get_characteristic("amplitude"),
-                'area': self._get_characteristic("area"),
-            }
+            self.result = []
+            for kind in ['min', 'max', 'amplitude', 'area']:
+                self.result.append(self._get_characteristic(kind))
 
     def _get_characteristic(self, kind=None, output="value"):
         function = getattr(self, '_get_characteristic_' + output)
@@ -802,6 +964,7 @@ class BasicCharacteristics(SingleAnalysisStep):
             result = np.ptp(self.dataset.data.data)
         if kind == "area":
             result = self.dataset.data.data.sum()
+        self.index.append(kind)
         return result
 
     def _get_characteristic_axes(self, kind=None):
@@ -812,12 +975,16 @@ class BasicCharacteristics(SingleAnalysisStep):
                                    self.dataset.data.data.shape)
             for dim in range(self.dataset.data.data.ndim):
                 result.append(self.dataset.data.axes[dim].values[idx[dim]])
+                self.index.append(
+                    '{}({})'.format(kind, self.dataset.data.axes[dim].quantity))
         if kind == "max":
             result = []
             idx = np.unravel_index(self.dataset.data.data.argmax(),
                                    self.dataset.data.data.shape)
             for dim in range(self.dataset.data.data.ndim):
                 result.append(self.dataset.data.axes[dim].values[idx[dim]])
+                self.index.append(
+                    '{}({})'.format(kind, self.dataset.data.axes[dim].quantity))
         return result
 
     def _get_characteristic_indices(self, kind=None):
@@ -825,9 +992,13 @@ class BasicCharacteristics(SingleAnalysisStep):
         if kind == "min":
             result = list(np.unravel_index(self.dataset.data.data.argmin(),
                                            self.dataset.data.data.shape))
+            for dim in range(self.dataset.data.data.ndim):
+                self.index.append('{}(index{})'.format(kind, dim))
         if kind == "max":
             result = list(np.unravel_index(self.dataset.data.data.argmax(),
                                            self.dataset.data.data.shape))
+            for dim in range(self.dataset.data.data.ndim):
+                self.index.append('{}(index{})'.format(kind, dim))
         return result
 
 
