@@ -226,7 +226,7 @@ import numpy as np
 import aspecd.dataset
 import aspecd.exceptions
 import aspecd.utils
-from aspecd.utils import not_zero, iterable
+from aspecd.utils import not_zero, isiterable
 
 
 class Model:
@@ -267,6 +267,13 @@ class Model:
     description : :class:`str`
         Short description, to be set in class definition
 
+    references : :class:`list`
+        List of references with relevance for the implementation of the
+        processing step.
+
+        Use appropriate record types from the `bibrecord package
+        <https://bibrecord.docs.till-biskup.de/>`_.
+
 
     .. versionchanged:: 0.3
         New attribute :attr:`description`
@@ -274,6 +281,9 @@ class Model:
     .. versionchanged:: 0.3
         New non-public method :meth:`_sanitise_parameters`
 
+    .. versionchanged:: 0.4
+        New attribute :attr:`references`
+
     """
 
     def __init__(self):
@@ -281,6 +291,7 @@ class Model:
         self.parameters = dict()
         self.variables = []
         self.description = 'Abstract model'
+        self.references = []
         self._dataset = aspecd.dataset.CalculatedDataset()
         self._axes_from_dataset = []
 
@@ -727,7 +738,7 @@ class FamilyOfCurves(Model):
     def _sanitise_parameters(self):
         if not self.model:
             raise ValueError('Missing a model')
-        if not iterable(self.vary["values"]):
+        if not isiterable(self.vary["values"]):
             self.vary["values"] = [self.vary["values"]]
         if not self.parameters:
             self.parameters[self.vary["parameter"]] = self.vary["values"][0]
@@ -896,16 +907,16 @@ class Zeros(Model):
                     message="Parameter 'shape' missing")
         if not self.parameters["shape"]:
             self.parameters["shape"] = []
-            if iterable(self.variables[0]):
+            if isiterable(self.variables[0]):
                 for index in range(len(self.variables)):
                     # noinspection PyTypeChecker
                     self.parameters["shape"].append(len(self.variables[index]))
             else:
                 self.parameters["shape"] = len(self.variables)
-        if not iterable(self.parameters["shape"]):
+        if not isiterable(self.parameters["shape"]):
             self.parameters["shape"] = [self.parameters["shape"]]
         if self.parameters["range"]:
-            if not iterable(self.parameters["range"][0]):
+            if not isiterable(self.parameters["range"][0]):
                 self.parameters["range"] = [self.parameters["range"]]
             if len(self.parameters["shape"]) != len(self.parameters["range"]):
                 raise IndexError('Shape and range must be compatible')
@@ -1065,16 +1076,16 @@ class Ones(Model):
                     message="Parameter 'shape' missing")
         if not self.parameters["shape"]:
             self.parameters["shape"] = []
-            if iterable(self.variables[0]):
+            if isiterable(self.variables[0]):
                 for index in range(len(self.variables)):
                     # noinspection PyTypeChecker
                     self.parameters["shape"].append(len(self.variables[index]))
             else:
                 self.parameters["shape"] = len(self.variables)
-        if not iterable(self.parameters["shape"]):
+        if not isiterable(self.parameters["shape"]):
             self.parameters["shape"] = [self.parameters["shape"]]
         if self.parameters["range"]:
-            if not iterable(self.parameters["range"][0]):
+            if not isiterable(self.parameters["range"][0]):
                 self.parameters["range"] = [self.parameters["range"]]
             if len(self.parameters["shape"]) != len(self.parameters["range"]):
                 raise IndexError('Shape and range must be compatible')
